%   [m, PDF_GRT, CDF_GRT]=dist_GRT(Md,Mu,dM,Mmin,eps,b,Mmax)
%
% EVALUATES THE DENSITY AND CUMULATIVE DISTRIBUTION FUNCTIONS OF MAGNITUDE
%   UNDER THE UPPER-BOUNDED G-R LED MAGNITUDE DISTRIBUTION MODEL. 
%
% AUTHOR: S. Lasocki 06/2014 within IS-EPOS project.
%
% DESCRIPTION: The assumption on the upper-bounded Gutenberg-Richter 
% relation leads to the upper truncated exponential distribution to model 
% magnitude distribution from and above the catalog completness level 
% Mmin. The shape parameter of this distribution, consequently the G-R
% b-value and the end-point of the distribution Mmax are calculated at 
% start-up of the stationary hazard assessment services in the
% upper-bounded Gutenberg-Richter estimation mode.
%
% The distribution function values are calculated for magnitude starting 
% from Md up to Mu with step dM.
%
%INPUT:
%   Md - starting magnitude for distribution functions calculations
%   Mu - ending magnitude for distribution functions calculations
%   dM - magnitude step for distribution functions calculations
%   Mmin - lower bound of the distribution - catalog completeness level
%   eps - length of the round-off interval of magnitudes.
%   b - Gutenberg-Richter b-value
%   Mmax - upper limit of magnitude distribution
%
%OUTPUT:
%   m - vector of the independent variable (magnitude) m=(Md:dM:Mu)
%   PDF_GRT - PDF vector of the same length as m
%   CDF_GRT - CDF vector of the same length as m
%
% LICENSE
%     This file is a part of the IS-EPOS e-PLATFORM.
%
%     This is free software: you can redistribute it and/or modify it under 
%     the terms of the GNU General Public License as published by the Free 
%     Software Foundation, either version 3 of the License, or 
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 


function [m, PDF_GRT, CDF_GRT]=dist_GRT(Md,Mu,dM,Mmin,eps,b,Mmax)

% -------------- VALIDATION RULES -------------  K_21NOV2016
 if dM<=0;error('Magnitude Step must be greater than 0');end
%----------------------------------------------------------

m=(Md:dM:Mu)';
beta=b*log(10);
mian=(1-exp(-beta*(Mmax-Mmin+eps/2))); 
PDF_GRT=beta*exp(-beta*(m-Mmin+eps/2))/mian;
CDF_GRT=(1-exp(-beta*(m-Mmin+eps/2)))/mian;
idx=find(CDF_GRT<0);
PDF_GRT(idx)=zeros(size(idx));CDF_GRT(idx)=zeros(size(idx));
idx=find(CDF_GRT>1);
PDF_GRT(idx)=zeros(size(idx));CDF_GRT(idx)=ones(size(idx));
end

